@@ -13,7 +13,7 @@ from .. import plot_commands as plotCmdStdHelp
 
 
 @serializationReg.registerForSerialization()
-class LinePlotter(shared.FromJsonMixin, plotterCoreHelp.SingleGraphPlotter):
+class LinePlotter(shared.FromJsonMixin, shared.FromPlotterMixin, plotterCoreHelp.SingleGraphPlotter):
 
 	def __init__(self, **kwargs):
 		""" Initializer
@@ -41,6 +41,7 @@ def _createCommandsList():
 	outList = [
 	plotCmdStdHelp.CreateFigureIfNoAxHandle(),
 	plotCmdStdHelp.PlotDataAsLines(),
+	plotCmdStdHelp.GridLinesCreate(),
 	plotCmdStdHelp.SetDataLabels(),
 	plotCmdStdHelp.SetLineColors(),
 	plotCmdStdHelp.SetLineMarkerSizes(),
@@ -80,6 +81,11 @@ def _createOptionsList():
 	plotOptStdHelp.AxisColorY_exclSpines(),
 	plotOptStdHelp.DataLabels(),
 	plotOptStdHelp.FontSizeDefault(),
+	plotOptStdHelp.GridLinesShow(value=False),
+	plotOptStdHelp.GridLinesShowX(),
+	plotOptStdHelp.GridLinesShowY(),
+	plotOptStdHelp.GridLinesStyle(),
+	plotOptStdHelp.GridLinesWidth(),
 	plotOptStdHelp.LegendFractPosStart(),
 	plotOptStdHelp.LegendLocStr(),
 	plotOptStdHelp.LegendNumbCols(),
